import * as Tiny from '@alipay/tiny.js';
import { Mesh3D } from '../mesh/mesh';
import { MaterialRenderType } from './material-render-type';
import { MeshShader } from '../mesh/mesh-shader';
import { Camera } from '../camera/camera';
/**
 * Materials are used to render a mesh with a specific visual appearance.
 */
export declare abstract class Material {
    protected _shader?: MeshShader;
    /** State used to render a mesh. */
    state: Tiny.State & {
        culling: boolean;
        clockwiseFrontFace: boolean;
        depthTest: boolean;
        blend: boolean;
    };
    /** Draw mode used to render a mesh. */
    drawMode: Tiny.DRAW_MODES;
    /** Render type used to render a mesh. This will determine in which order
     * the material is being rendered compared to other materials. */
    private _renderType;
    /**
     * The camera used when rendering a mesh. If this value is not set, the main
     * camera will be used by default.
     */
    camera?: Camera;
    get renderType(): MaterialRenderType;
    set renderType(type: MaterialRenderType);
    /** shader */
    get shader(): MeshShader;
    /** Value indicating if the material is double sided. */
    get doubleSided(): boolean;
    set doubleSided(value: boolean);
    get depthMask(): boolean;
    set depthMask(value: boolean);
    /** Blend mode used to render a mesh. */
    get blendMode(): Tiny.BLEND_MODES;
    set blendMode(value: Tiny.BLEND_MODES);
    /**
     * Creates a shader used to render the specified mesh.
     * @param mesh The mesh to create the shader for.
     * @param renderer The renderer to use.
     */
    abstract createShader(mesh: Mesh3D, renderer: Tiny.Renderer): MeshShader | undefined;
    /**
     * Updates the uniforms for the specified shader.
     * @param mesh The mesh used for updating the uniforms.
     * @param shader The shader to update.
     */
    abstract updateUniforms?(mesh: Mesh3D, shader: MeshShader): void;
    /**
     * Destroys the material and it's used resources.
     */
    destroy(_options: any): void;
    /**
     * Returns a value indicating if this material supports instancing.
     */
    get isInstancingSupported(): boolean;
    /**
       * Creates a new instanced version of this material.
       */
    createInstance(): unknown;
    /**
     * Renders the specified mesh.
     * @param mesh The mesh to render.
     * @param renderer The renderer to use.
     */
    render(mesh: Mesh3D, renderer: Tiny.Renderer): void;
}
