import * as Tiny from '@alipay/tiny.js';
import { MeshGeometry3D } from './geometry/mesh-geometry';
import { Material } from '../material/material';
import { Container3D } from '../container';
import { Skin } from '../skinning/skin';
import { InstancedMesh3D } from './instanced-mesh';
import { Box3, Vector3, Sphere, Ray } from '@tinyjs-plugin-three/math';
import { RayCastOption } from '../RayCaster';
export declare function getGeometryValues(data: any, size: any): number[][];
export interface MeshDestroyOptions extends Tiny.IDestroyOptions {
    geometry?: boolean;
    material?: boolean;
}
/**
 * Represents a mesh which contains geometry and has a material.
 */
export declare class Mesh3D extends Container3D {
    geometry: MeshGeometry3D;
    material?: Material;
    /** The name of the plugin used for rendering the mesh. */
    pluginName: string;
    /** Array of weights used for morphing between geometry targets. */
    morphWeights?: number[];
    /** The skin used for vertex skinning. */
    skin?: Skin;
    /** Names of the passes used for rendering the mesh. */
    renderPasses: string[];
    /** Used for sorting the mesh before render. */
    renderSortOrder: number;
    resolution: number;
    localBoundingBox?: Box3;
    localBoundingSphere?: Sphere;
    private _worldBoundingBox;
    private _worldBoundingBoxId;
    /**
     * 当相机开启视锥裁剪时，是否允许裁剪
     * */
    enableFrustumCulling: boolean;
    /**
     * Creates a new mesh with the specified geometry and material.
     * @param geometry The geometry for the mesh.
     * @param material The material for the mesh. If the material is empty the mesh won't be rendered.
     */
    constructor(geometry: MeshGeometry3D, material?: Material);
    private _instances;
    /** An array of instances created from this mesh. */
    get instances(): InstancedMesh3D[];
    pickingInstance: InstancedMesh3D;
    /**
     * Creates a new instance of this mesh.
     */
    createInstance(pickingId?: Uint8Array): InstancedMesh3D;
    /**
       * Removes an instance from this mesh.
       * @param instance The instance to remove.
       */
    removeInstance(instance: InstancedMesh3D): void;
    setLocalBoundingBox(min: Vector3, max: Vector3): Box3;
    /**
     * local boundingBox
     */
    getLocalBoundingBox(useSkinEffect?: boolean): Box3;
    /**
     * transform 到世界坐标系的 boundingBox
    */
    getWorldBoundingBox(): Box3;
    /**
     * local boundingSphere
    */
    getLocalBoundingSphere(): Sphere;
    /**
     * 世界坐标系的 boundingSphere
    */
    getWorldBoundingSphere(): Sphere;
    /**
     * 计算光线和当前节点相交
     * @param option RayCastOption 光线投射参数
     * @param instanceMesh 是否是通过 instance 创建的 mesh
     */
    rayCast(option: RayCastOption, instance?: InstancedMesh3D): void;
    checkTriangleIntersection(options: {
        pointA: number[];
        pointB: number[];
        pointC: number[];
        ray: Ray;
        instance?: InstancedMesh3D;
    } & RayCastOption): void;
    /**
     * Destroys the mesh and it's used resources.
     */
    destroy(options?: boolean | MeshDestroyOptions): void;
    _render(renderer: Tiny.Renderer): void;
    protected _calculateBounds(): void;
    getVertices(): number[][];
    calculateVertices(): Float32Array;
    /**
     * Creates a new quad (flat square) mesh with the specified material.
     * @param material The material to use.
     */
    static createQuad(material?: Material): Mesh3D;
    /**
     * Creates a new cube (six faces) mesh with the specified material.
     * @param material The material to use.
     */
    static createCube(material?: Material): Mesh3D;
    /**
     * Creates a new plane (flat square) mesh with the specified material.
     * @param material The material to use.
     */
    static createPlane(material?: Material): Mesh3D;
}
